@@ -159,9 +159,10 @@ var CROWD_PICKER = new function() {
         {
 
             AJS.$("button:contains('" + actionButtonName + "')").click(function() {
-                AJS.$("#selectedentities").attr("action", actionURL);
-                AJS.$("#selectedentities").submit();
+                AJS.$("#selectentities").attr("action", actionURL);
+                AJS.$("#selectentities").submit();
             });
+
         }
 
     };
