@@ -10,7 +10,7 @@ public class Logoff extends BaseAction
 
     public String execute() throws Exception
     {
-        httpAuthenticator.logoff(ServletActionContext.getRequest(), ServletActionContext.getResponse());
+        crowdHttpAuthenticator.logout(ServletActionContext.getRequest(), ServletActionContext.getResponse());
 
         getSession().invalidate();
 
