@@ -15,7 +15,7 @@ public class RemoveGroup extends BaseAction
         try
         {
             // make sure the group exist, display errors if there is a problem
-            securityServerClient.findGroupByName(name);
+            crowdClient.getGroup(name);
 
         }
         catch (Exception e)
@@ -31,8 +31,7 @@ public class RemoveGroup extends BaseAction
     {
         try
         {
-
-            securityServerClient.removeGroup(name);
+            crowdClient.removeGroup(name);
 
             return SUCCESS;
 
