@@ -3,7 +3,7 @@
  */
 package com.atlassian.crowd.security.demo.action.group;
 
-import com.atlassian.crowd.integration.soap.SOAPGroup;
+import com.atlassian.crowd.model.group.Group;
 import com.atlassian.crowd.security.demo.action.BaseAction;
 import org.apache.log4j.Logger;
 
@@ -11,7 +11,7 @@ public class ViewGroup extends BaseAction
 {
     private static final Logger logger = Logger.getLogger(ViewGroup.class);
 
-    private SOAPGroup group;
+    private Group group;
 
     private String name;
     private String groupDescription;
@@ -21,7 +21,7 @@ public class ViewGroup extends BaseAction
     {
         try
         {
-            group = securityServerClient.findGroupByName(name);
+            group = crowdClient.getGroup(name);
 
             this.groupDescription = group.getDescription();
             this.active = group.isActive();
@@ -36,7 +36,7 @@ public class ViewGroup extends BaseAction
         return SUCCESS;
     }
 
-    public SOAPGroup getGroup()
+    public Group getGroup()
     {
         return group;
     }
